Documentation
¶
Index ¶
- Constants
- Variables
- type AliyunClient
- func (client *AliyunClient) AccountId() (string, error)
- func (client *AliyunClient) GetCallerIdentity() (*sts.GetCallerIdentityResponse, error)
- func (client *AliyunClient) NewActiontrailClient() (*rpc.Client, error)
- func (client *AliyunClient) NewAdbClient() (*rpc.Client, error)
- func (client *AliyunClient) NewAistudioClient() (*rpc.Client, error)
- func (client *AliyunClient) NewBssopenapiClient() (*rpc.Client, error)
- func (client *AliyunClient) NewCmsClient() (*rpc.Client, error)
- func (client *AliyunClient) NewCommonRequest(product, serviceCode, schema string, apiVersion ApiVersion) (*requests.CommonRequest, error)
- func (client *AliyunClient) NewConfigClient() (*rpc.Client, error)
- func (client *AliyunClient) NewDcdnClient() (*rpc.Client, error)
- func (client *AliyunClient) NewDmsenterpriseClient() (*rpc.Client, error)
- func (client *AliyunClient) NewEciClient() (*rpc.Client, error)
- func (client *AliyunClient) NewEcsClient() (*rpc.Client, error)
- func (client *AliyunClient) NewEipanycastClient() (*rpc.Client, error)
- func (client *AliyunClient) NewFnfClient() (*rpc.Client, error)
- func (client *AliyunClient) NewGaplusClient() (*rpc.Client, error)
- func (client *AliyunClient) NewHitsdbClient() (*rpc.Client, error)
- func (client *AliyunClient) NewImsClient() (*rpc.Client, error)
- func (client *AliyunClient) NewMseClient() (*rpc.Client, error)
- func (client *AliyunClient) NewNasClient() (*rpc.Client, error)
- func (client *AliyunClient) NewOdpsClient() (*rpc.Client, error)
- func (client *AliyunClient) NewOnsClient() (*rpc.Client, error)
- func (client *AliyunClient) NewOosClient() (*rpc.Client, error)
- func (client *AliyunClient) NewPrivatelinkClient() (*rpc.Client, error)
- func (client *AliyunClient) NewPvtzClient() (*rpc.Client, error)
- func (client *AliyunClient) NewQuotasClient() (*rpc.Client, error)
- func (client *AliyunClient) NewRamClient() (*rpc.Client, error)
- func (client *AliyunClient) NewRdsClient() (*rpc.Client, error)
- func (client *AliyunClient) NewResourcemanagerClient() (*rpc.Client, error)
- func (client *AliyunClient) NewRessharingClient() (*rpc.Client, error)
- func (client *AliyunClient) NewRosClient() (*rpc.Client, error)
- func (client *AliyunClient) NewTeaCommonClient(endpoint string) (*rpc.Client, error)
- func (client *AliyunClient) NewTeaRoaCommonClient(endpoint string) (*roa.Client, error)
- func (client *AliyunClient) NewVpcClient() (*rpc.Client, error)
- func (client *AliyunClient) NewWafClient() (*rpc.Client, error)
- func (client *AliyunClient) WithAdbClient(do func(*adb.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithAlidnsClient(do func(*alidns.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithAlikafkaClient(do func(*alikafka.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithBastionhostClient(do func(*yundun_bastionhost.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithBssopenapiClient(do func(*bssopenapi.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithCasClient(do func(*cas.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithCassandraClient(do func(*cassandra.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithCbnClient(do func(*cbn.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithCdnClient(do func(*cdn.CdnClient) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithCdnClient_new(do func(*cdn_new.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithCenClient(do func(*cbn.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithCloudApiClient(do func(*cloudapi.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithCmsClient(do func(*cms.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithCrClient(do func(*cr.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithCrEEClient(do func(*cr_ee.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithCsClient(do func(*cs.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithCsProjectClient(clusterId, endpoint string, clusterCerts cs.ClusterCerts, ...) (interface{}, error)
- func (client *AliyunClient) WithDataHubClient(do func(*datahub.DataHub) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithDbauditClient(do func(*yundun_dbaudit.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithDcdnClient(do func(*dcdn.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithDdosbgpClient(do func(*ddosbgp.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithDdoscooClient(do func(*ddoscoo.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithDdsClient(do func(*dds.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithDnsClient(do func(*alidns.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithDrdsClient(do func(*drds.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithEciClient(do func(*eci.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithEcsClient(do func(*ecs.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithEdasClient(do func(*edas.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithElasticsearchClient(do func(*elasticsearch.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithEmrClient(do func(*emr.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithEssClient(do func(*ess.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithFcClient(do func(*fc.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithGpdbClient(do func(*gpdb.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithHbaseClient(do func(*hbase.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithKmsClient(do func(*kms.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithLogClient(do func(*sls.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithLogPopClient(do func(*slsPop.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithMarketClient(do func(*market.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithMnsClient(do func(*ali_mns.MNSClient) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithMnsQueueManager(do func(ali_mns.AliQueueManager) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithMnsSubscriptionManagerByTopicName(topicName string, do func(ali_mns.AliMNSTopic) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithMnsTopicManager(do func(ali_mns.AliTopicManager) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithOfficalCSClient(do func(*officalCS.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithOssBucketByName(bucketName string, do func(*oss.Bucket) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithOssClient(do func(*oss.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithOtsClient(do func(*ots.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithPolarDBClient(do func(*polardb.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithRKvstoreClient(do func(*r_kvstore.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithRamClient(do func(*ram.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithRdsClient(do func(*rds.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithRkvClient(do func(*r_kvstore.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithSagClient(do func(*smartag.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithSlbClient(do func(*slb.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithStsClient(do func(*sts.Client) (interface{}, error)) (interface{}, error)
- func (client *AliyunClient) WithTableStoreClient(instanceName string, ...) (interface{}, error)
- func (client *AliyunClient) WithVpcClient(do func(*vpc.Client) (interface{}, error)) (interface{}, error)
- type ApiVersion
- type Config
- type Endpoint
- type Endpoints
- type Product
- type Products
- type Region
- type RegionIds
- type ServiceCode
Constants ¶
const ( ApiVersion20140526 = ApiVersion("2014-05-26") ApiVersion20160815 = ApiVersion("2016-08-15") ApiVersion20140515 = ApiVersion("2014-05-15") )
const ( MaxcomputeCode = ServiceCode("MAXCOMPUTE") CmsCode = ServiceCode("CMS") RKvstoreCode = ServiceCode("RKVSTORE") OnsCode = ServiceCode("ONS") DcdnCode = ServiceCode("DCDN") MseCode = ServiceCode("MSE") ActiontrailCode = ServiceCode("ACTIONTRAIL") OosCode = ServiceCode("OOS") EcsCode = ServiceCode("ECS") NasCode = ServiceCode("NAS") EciCode = ServiceCode("ECI") DdoscooCode = ServiceCode("DDOSCOO") BssopenapiCode = ServiceCode("BSSOPENAPI") AlidnsCode = ServiceCode("ALIDNS") ResourcemanagerCode = ServiceCode("RESOURCEMANAGER") WafOpenapiCode = ServiceCode("WAFOPENAPI") DmsEnterpriseCode = ServiceCode("DMSENTERPRISE") DnsCode = ServiceCode("DNS") KmsCode = ServiceCode("KMS") CbnCode = ServiceCode("CBN") ECSCode = ServiceCode("ECS") ESSCode = ServiceCode("ESS") RAMCode = ServiceCode("RAM") VPCCode = ServiceCode("VPC") SLBCode = ServiceCode("SLB") RDSCode = ServiceCode("RDS") OSSCode = ServiceCode("OSS") ONSCode = ServiceCode("ONS") ALIKAFKACode = ServiceCode("ALIKAFKA") CONTAINCode = ServiceCode("CS") CRCode = ServiceCode("CR") CDNCode = ServiceCode("CDN") CMSCode = ServiceCode("CMS") KMSCode = ServiceCode("KMS") OTSCode = ServiceCode("OTS") DNSCode = ServiceCode("DNS") PVTZCode = ServiceCode("PVTZ") LOGCode = ServiceCode("LOG") FCCode = ServiceCode("FC") DDSCode = ServiceCode("DDS") GPDBCode = ServiceCode("GPDB") STSCode = ServiceCode("STS") CENCode = ServiceCode("CEN") KVSTORECode = ServiceCode("KVSTORE") POLARDBCode = ServiceCode("POLARDB") DATAHUBCode = ServiceCode("DATAHUB") MNSCode = ServiceCode("MNS") CLOUDAPICode = ServiceCode("APIGATEWAY") DRDSCode = ServiceCode("DRDS") LOCATIONCode = ServiceCode("LOCATION") ELASTICSEARCHCode = ServiceCode("ELASTICSEARCH") BSSOPENAPICode = ServiceCode("BSSOPENAPI") DDOSCOOCode = ServiceCode("DDOSCOO") DDOSBGPCode = ServiceCode("DDOSBGP") SAGCode = ServiceCode("SAG") EMRCode = ServiceCode("EMR") CasCode = ServiceCode("CAS") YUNDUNDBAUDITCode = ServiceCode("YUNDUNDBAUDIT") MARKETCode = ServiceCode("MARKET") HBASECode = ServiceCode("HBASE") ADBCode = ServiceCode("ADB") MAXCOMPUTECode = ServiceCode("MAXCOMPUTE") EDASCode = ServiceCode("EDAS") CassandraCode = ServiceCode("CASSANDRA") )
const ( OpenApiGatewayService = "apigateway.cn-hangzhou.aliyuncs.com" OpenSlsService = "sls.aliyuncs.com" OpenOtsService = "ots.cn-hangzhou.aliyuncs.com" OpenOssService = "oss-admin.aliyuncs.com" OpenNasService = "nas.cn-hangzhou.aliyuncs.com" OpenCdnService = "cdn.aliyuncs.com" OpenBssService = "business.aliyuncs.com" OpenKmsService = "kms.cn-hangzhou.aliyuncs.com" OpenCmsService = "metrics.cn-hangzhou.aliyuncs.com" OpenDatahubService = "datahub.aliyuncs.com" OpenOnsService = "ons.cn-hangzhou.aliyuncs.com" OpenDcdnService = "dcdn.aliyuncs.com" OpenFcService = "fc-open.cn-hangzhou.aliyuncs.com" OpenAckService = "cs.aliyuncs.com" OpenPrivateLinkService = "privatelink.cn-hangzhou.aliyuncs.com" OpenBrainIndustrialService = "brain-industrial-share.cn-hangzhou.aliyuncs.com" OpenIotService = "iot.aliyuncs.com" )
const ( Hangzhou = Region("cn-hangzhou") Qingdao = Region("cn-qingdao") Beijing = Region("cn-beijing") Hongkong = Region("cn-hongkong") Shenzhen = Region("cn-shenzhen") Shanghai = Region("cn-shanghai") Zhangjiakou = Region("cn-zhangjiakou") Huhehaote = Region("cn-huhehaote") ChengDu = Region("cn-chengdu") HeYuan = Region("cn-heyuan") WuLanChaBu = Region("cn-wulanchabu") GuangZhou = Region("cn-guangzhou") APSouthEast1 = Region("ap-southeast-1") APNorthEast1 = Region("ap-northeast-1") APSouthEast2 = Region("ap-southeast-2") APSouthEast3 = Region("ap-southeast-3") APSouthEast5 = Region("ap-southeast-5") APSouth1 = Region("ap-south-1") USWest1 = Region("us-west-1") USEast1 = Region("us-east-1") MEEast1 = Region("me-east-1") EUCentral1 = Region("eu-central-1") EUWest1 = Region("eu-west-1") ShenZhenFinance = Region("cn-shenzhen-finance-1") ShanghaiFinance = Region("cn-shanghai-finance-1") ShanghaiFinance1Pub = Region("cn-shanghai-finance-1-pub") CnNorth2Gov1 = Region("cn-north-2-gov-1") )
Constants of region definition
const DefaultClientRetryCountLarge = 15
const DefaultClientRetryCountMedium = 10
const DefaultClientRetryCountSmall = 5
const Module = "Terraform-Module"
const Provider = "Terraform-Provider"
const Terraform = "HashiCorp-Terraform"
Variables ¶
var ActiontrailNoSkipRegions = []Region{Hangzhou, EUCentral1, APSouth1}
Actiontrail only one can be owned by one account at the same time, skipped here to avoid multi regions concurrency conflict.
var AlikafkaSupportedRegions = []Region{Hangzhou, Qingdao, Beijing, Hongkong, Shenzhen, Shanghai, Zhangjiakou, Huhehaote, ChengDu, HeYuan, APNorthEast1, APSouthEast1, APSouthEast3, EUCentral1, EUWest1, USEast1, USWest1}
var ApiGatewayNoSupportedRegions = []Region{Zhangjiakou, Huhehaote, USEast1, USWest1, EUWest1, MEEast1}
var BrainIndustrialRegions = []Region{Hangzhou}
var CRNoSupportedRegions = []Region{Beijing, Hangzhou, Qingdao, Huhehaote, Zhangjiakou}
var CasClassicSupportedRegions = []Region{Hangzhou, APSouth1, MEEast1, EUCentral1, APNorthEast1, APSouthEast2}
var CenNoSkipRegions = []Region{Shanghai, EUCentral1, APSouth1}
var CloudConfigSupportedRegions = []Region{Shanghai, APSouthEast1}
var DBReadwriteSplittingConnectionSupportedRegions = []Region{APSouthEast1}
var DatahubSupportedRegions = []Region{Beijing, Hangzhou, Shanghai, Shenzhen, APSouthEast1}
var DdosbgpSupportedRegions = []Region{Hangzhou, Beijing, Shenzhen, Qingdao, Shanghai, Zhangjiakou, Huhehaote}
var DdoscooSupportedRegions = []Region{Hangzhou}
var DrdsClassicNoSupportedRegions = []Region{Hongkong}
var DrdsSupportedRegions = []Region{Beijing, Shenzhen, Hangzhou, Qingdao, Hongkong, Shanghai, Huhehaote, Zhangjiakou, APSouthEast1}
var EciContainerGroupRegions = []Region{Beijing}
var EcsClassicSupportedRegions = []Region{Shenzhen, Shanghai, Beijing, Qingdao, Hangzhou, Hongkong, USWest1, APSouthEast1}
var EcsSpotNoSupportedRegions = []Region{APSouth1}
var EdasSupportedRegions = []Region{Hangzhou, Beijing, Shanghai, Shenzhen, Zhangjiakou, Qingdao, Hongkong}
var EipanycastSupportRegions = []Region{Hangzhou}
var EssScalingConfigurationMultiSgSupportedRegions = []Region{APSouthEast1, APSouth1}
var FcNoSupportedRegions = []Region{MEEast1}
var GpdbClassicNoSupportedRegions = []Region{APSouthEast2, APSouthEast3, APSouthEast5, APSouth1, USEast1, USWest1, APNorthEast1, EUCentral1}
var HttpHttpsHealthCheckMehtodSupportedRegions = []Region{Hangzhou, Beijing, Shanghai, EUWest1, ChengDu, Qingdao, Hongkong, Shenzhen, APSouthEast5, Zhangjiakou, Huhehaote, MEEast1, APSouth1, EUCentral1, USWest1, APSouthEast3, APSouthEast2, APSouthEast1, APNorthEast1}
var KVstoreClassicNetworkInstanceSupportRegions = []Region{}
var KmsSkippedRegions = []Region{Beijing, Shanghai}
var KubernetesSupportedRegions = []Region{Beijing, Zhangjiakou, Huhehaote, Hangzhou, Shanghai, Shenzhen, Hongkong, APNorthEast1, APSouthEast1, APSouthEast2, APSouthEast3, APSouthEast5, APSouth1, USEast1, USWest1, EUWest1, MEEast1, EUCentral1}
var ManagedKubernetesSupportedRegions = []Region{Beijing, Hangzhou, Shanghai, Shenzhen, ChengDu, Hongkong, APSouthEast1, APSouthEast2, USWest1}
var MaxComputeSupportRegions = []Region{}
var MongoDBClassicNoSupportedRegions = []Region{Huhehaote, Zhangjiakou, APSouthEast2, APSouthEast3, APSouthEast5, APSouth1, USEast1, USWest1, APNorthEast1}
var MongoDBMultiAzSupportedRegions = []Region{Hangzhou, Beijing, Shenzhen, EUCentral1}
var NasClassicSupportedRegions = []Region{Hangzhou, Qingdao, Beijing, Hongkong, Shenzhen, Shanghai, Zhangjiakou, Huhehaote, ShenZhenFinance, ShanghaiFinance}
var NasNoSupportedRegions = []Region{Qingdao, APSouth1, APSouthEast3, APSouthEast5}
var NetworkAclSupportedRegions = []Region{Hongkong, APSouthEast5, APSouth1}
var OnsNoSupportRegions = []Region{APSouthEast5}
var OssSseSupportedRegions = []Region{Qingdao, Hangzhou, Beijing, Shanghai, Shenzhen, Hongkong, APNorthEast1, APSouth1, USEast1}
var OssVersioningSupportedRegions = []Region{APSouth1}
var OtsCapacityNoSupportedRegions = []Region{APSouthEast1, USWest1, USEast1}
var OtsHighPerformanceNoSupportedRegions = []Region{Qingdao, Zhangjiakou, Huhehaote, Hongkong, APSouthEast2, APSouthEast5, APNorthEast1, EUCentral1, MEEast1, APSouth1}
var PrivateIpNoSupportedRegions = []Region{Beijing, Hangzhou, Shenzhen}
var PrivateLinkRegions = []Region{EUCentral1}
var RamNoSkipRegions = []Region{Hangzhou, EUCentral1, APSouth1}
Some Ram resources only one can be owned by one account at the same time, skipped here to avoid multi regions concurrency conflict.
var RdsClassicNoSupportedRegions = []Region{APSouth1, APSouthEast2, APSouthEast3, APNorthEast1, EUCentral1, EUWest1, MEEast1}
var RdsMultiAzNoSupportedRegions = []Region{Qingdao, APNorthEast1, APSouthEast5, MEEast1}
var RdsPPASNoSupportedRegions = []Region{Qingdao, USEast1, APNorthEast1, EUCentral1, MEEast1, APSouthEast2, APSouthEast3, APSouth1, APSouthEast5, ChengDu, EUWest1}
var RouteTableNoSupportedRegions = []Region{Beijing, Hangzhou, Shenzhen}
var ServerlessKubernetesSupportedRegions = []Region{Beijing, Hangzhou, Shanghai, APSouthEast1, APSouthEast3, APSouthEast5, APSouth1}
var SlbClassicNoSupportedRegions = []Region{APNorthEast1, APSouthEast2, APSouthEast3, APSouthEast5, APSouth1, USEast1, MEEast1, EUCentral1, EUWest1, Huhehaote, Zhangjiakou}
var SlbGuaranteedSupportedRegions = []Region{Qingdao, Beijing, Hangzhou, Shanghai, Shenzhen, Zhangjiakou, Huhehaote, APSouthEast1, USEast1}
var SmartagSupportedRegions = []Region{Shanghai, ShanghaiFinance, Hongkong, APSouthEast1, APSouthEast2, APSouthEast3, APSouthEast5, EUCentral1, APNorthEast1}
var SwarmSupportedRegions = []Region{Qingdao, Beijing, Zhangjiakou, Huhehaote, Hangzhou, Shanghai, Shenzhen, Hongkong, APNorthEast1, APSouthEast1, APSouthEast2, APSouthEast3, USWest1, USEast1, EUCentral1}
var TsdbInstanceSupportRegions = []Region{Beijing, Hangzhou, Shenzhen, Shanghai, ShenZhenFinance, Qingdao, Zhangjiakou, ShanghaiFinance, Hongkong, USWest1, APNorthEast1, EUWest1, APSouthEast1, APSouthEast2, APSouthEast3, EUCentral1, APSouthEast5, Zhangjiakou, CnNorth2Gov1}
var ValidRegions = []Region{ Hangzhou, Qingdao, Beijing, Shenzhen, Hongkong, Shanghai, Zhangjiakou, Huhehaote, ChengDu, HeYuan, WuLanChaBu, GuangZhou, USWest1, USEast1, APNorthEast1, APSouthEast1, APSouthEast2, APSouthEast3, APSouthEast5, APSouth1, MEEast1, EUCentral1, EUWest1, ShenZhenFinance, ShanghaiFinance, CnNorth2Gov1, ShanghaiFinance1Pub, }
var YundunBastionhostSupportedRegions = []Region{Hangzhou}
var YundunDbauditSupportedRegions = []Region{Hangzhou, Beijing, Shanghai}
Functions ¶
This section is empty.
Types ¶
type AliyunClient ¶
type AliyunClient struct {
Region Region
RegionId string
SourceIp string
//In order to build ots table client, add accesskey and secretkey in aliyunclient temporarily.
AccessKey string
SecretKey string
SecurityToken string
OtsInstanceName string
// contains filtered or unexported fields
}
func (*AliyunClient) AccountId ¶
func (client *AliyunClient) AccountId() (string, error)
func (*AliyunClient) GetCallerIdentity ¶
func (client *AliyunClient) GetCallerIdentity() (*sts.GetCallerIdentityResponse, error)
func (*AliyunClient) NewActiontrailClient ¶
func (client *AliyunClient) NewActiontrailClient() (*rpc.Client, error)
func (*AliyunClient) NewAdbClient ¶
func (client *AliyunClient) NewAdbClient() (*rpc.Client, error)
func (*AliyunClient) NewAistudioClient ¶
func (client *AliyunClient) NewAistudioClient() (*rpc.Client, error)
func (*AliyunClient) NewBssopenapiClient ¶
func (client *AliyunClient) NewBssopenapiClient() (*rpc.Client, error)
func (*AliyunClient) NewCmsClient ¶
func (client *AliyunClient) NewCmsClient() (*rpc.Client, error)
func (*AliyunClient) NewCommonRequest ¶
func (client *AliyunClient) NewCommonRequest(product, serviceCode, schema string, apiVersion ApiVersion) (*requests.CommonRequest, error)
func (*AliyunClient) NewConfigClient ¶
func (client *AliyunClient) NewConfigClient() (*rpc.Client, error)
func (*AliyunClient) NewDcdnClient ¶
func (client *AliyunClient) NewDcdnClient() (*rpc.Client, error)
func (*AliyunClient) NewDmsenterpriseClient ¶
func (client *AliyunClient) NewDmsenterpriseClient() (*rpc.Client, error)
func (*AliyunClient) NewEciClient ¶
func (client *AliyunClient) NewEciClient() (*rpc.Client, error)
func (*AliyunClient) NewEcsClient ¶
func (client *AliyunClient) NewEcsClient() (*rpc.Client, error)
func (*AliyunClient) NewEipanycastClient ¶
func (client *AliyunClient) NewEipanycastClient() (*rpc.Client, error)
func (*AliyunClient) NewFnfClient ¶
func (client *AliyunClient) NewFnfClient() (*rpc.Client, error)
func (*AliyunClient) NewGaplusClient ¶
func (client *AliyunClient) NewGaplusClient() (*rpc.Client, error)
func (*AliyunClient) NewHitsdbClient ¶
func (client *AliyunClient) NewHitsdbClient() (*rpc.Client, error)
func (*AliyunClient) NewImsClient ¶
func (client *AliyunClient) NewImsClient() (*rpc.Client, error)
func (*AliyunClient) NewMseClient ¶
func (client *AliyunClient) NewMseClient() (*rpc.Client, error)
func (*AliyunClient) NewNasClient ¶
func (client *AliyunClient) NewNasClient() (*rpc.Client, error)
func (*AliyunClient) NewOdpsClient ¶
func (client *AliyunClient) NewOdpsClient() (*rpc.Client, error)
func (*AliyunClient) NewOnsClient ¶
func (client *AliyunClient) NewOnsClient() (*rpc.Client, error)
func (*AliyunClient) NewOosClient ¶
func (client *AliyunClient) NewOosClient() (*rpc.Client, error)
func (*AliyunClient) NewPrivatelinkClient ¶
func (client *AliyunClient) NewPrivatelinkClient() (*rpc.Client, error)
func (*AliyunClient) NewPvtzClient ¶
func (client *AliyunClient) NewPvtzClient() (*rpc.Client, error)
func (*AliyunClient) NewQuotasClient ¶
func (client *AliyunClient) NewQuotasClient() (*rpc.Client, error)
func (*AliyunClient) NewRamClient ¶
func (client *AliyunClient) NewRamClient() (*rpc.Client, error)
func (*AliyunClient) NewRdsClient ¶
func (client *AliyunClient) NewRdsClient() (*rpc.Client, error)
func (*AliyunClient) NewResourcemanagerClient ¶
func (client *AliyunClient) NewResourcemanagerClient() (*rpc.Client, error)
func (*AliyunClient) NewRessharingClient ¶
func (client *AliyunClient) NewRessharingClient() (*rpc.Client, error)
func (*AliyunClient) NewRosClient ¶
func (client *AliyunClient) NewRosClient() (*rpc.Client, error)
func (*AliyunClient) NewTeaCommonClient ¶
func (client *AliyunClient) NewTeaCommonClient(endpoint string) (*rpc.Client, error)
func (*AliyunClient) NewTeaRoaCommonClient ¶
func (client *AliyunClient) NewTeaRoaCommonClient(endpoint string) (*roa.Client, error)
func (*AliyunClient) NewVpcClient ¶
func (client *AliyunClient) NewVpcClient() (*rpc.Client, error)
func (*AliyunClient) NewWafClient ¶
func (client *AliyunClient) NewWafClient() (*rpc.Client, error)
func (*AliyunClient) WithAdbClient ¶
func (client *AliyunClient) WithAdbClient(do func(*adb.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithAlidnsClient ¶
func (client *AliyunClient) WithAlidnsClient(do func(*alidns.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithAlikafkaClient ¶
func (client *AliyunClient) WithAlikafkaClient(do func(*alikafka.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithBastionhostClient ¶
func (client *AliyunClient) WithBastionhostClient(do func(*yundun_bastionhost.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithBssopenapiClient ¶
func (client *AliyunClient) WithBssopenapiClient(do func(*bssopenapi.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithCasClient ¶
func (client *AliyunClient) WithCasClient(do func(*cas.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithCassandraClient ¶
func (client *AliyunClient) WithCassandraClient(do func(*cassandra.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithCbnClient ¶
func (client *AliyunClient) WithCbnClient(do func(*cbn.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithCdnClient ¶
func (client *AliyunClient) WithCdnClient(do func(*cdn.CdnClient) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithCdnClient_new ¶
func (client *AliyunClient) WithCdnClient_new(do func(*cdn_new.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithCenClient ¶
func (client *AliyunClient) WithCenClient(do func(*cbn.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithCloudApiClient ¶
func (client *AliyunClient) WithCloudApiClient(do func(*cloudapi.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithCmsClient ¶
func (client *AliyunClient) WithCmsClient(do func(*cms.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithCrClient ¶
func (client *AliyunClient) WithCrClient(do func(*cr.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithCrEEClient ¶
func (client *AliyunClient) WithCrEEClient(do func(*cr_ee.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithCsClient ¶
func (client *AliyunClient) WithCsClient(do func(*cs.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithCsProjectClient ¶
func (client *AliyunClient) WithCsProjectClient(clusterId, endpoint string, clusterCerts cs.ClusterCerts, do func(*cs.ProjectClient) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithDataHubClient ¶
func (client *AliyunClient) WithDataHubClient(do func(*datahub.DataHub) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithDbauditClient ¶
func (client *AliyunClient) WithDbauditClient(do func(*yundun_dbaudit.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithDcdnClient ¶
func (client *AliyunClient) WithDcdnClient(do func(*dcdn.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithDdosbgpClient ¶
func (client *AliyunClient) WithDdosbgpClient(do func(*ddosbgp.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithDdoscooClient ¶
func (client *AliyunClient) WithDdoscooClient(do func(*ddoscoo.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithDdsClient ¶
func (client *AliyunClient) WithDdsClient(do func(*dds.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithDnsClient ¶
func (client *AliyunClient) WithDnsClient(do func(*alidns.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithDrdsClient ¶
func (client *AliyunClient) WithDrdsClient(do func(*drds.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithEciClient ¶
func (client *AliyunClient) WithEciClient(do func(*eci.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithEcsClient ¶
func (client *AliyunClient) WithEcsClient(do func(*ecs.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithEdasClient ¶
func (client *AliyunClient) WithEdasClient(do func(*edas.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithElasticsearchClient ¶
func (client *AliyunClient) WithElasticsearchClient(do func(*elasticsearch.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithEmrClient ¶
func (client *AliyunClient) WithEmrClient(do func(*emr.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithEssClient ¶
func (client *AliyunClient) WithEssClient(do func(*ess.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithFcClient ¶
func (client *AliyunClient) WithFcClient(do func(*fc.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithGpdbClient ¶
func (client *AliyunClient) WithGpdbClient(do func(*gpdb.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithHbaseClient ¶
func (client *AliyunClient) WithHbaseClient(do func(*hbase.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithKmsClient ¶
func (client *AliyunClient) WithKmsClient(do func(*kms.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithLogClient ¶
func (client *AliyunClient) WithLogClient(do func(*sls.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithLogPopClient ¶
func (client *AliyunClient) WithLogPopClient(do func(*slsPop.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithMarketClient ¶
func (client *AliyunClient) WithMarketClient(do func(*market.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithMnsClient ¶
func (client *AliyunClient) WithMnsClient(do func(*ali_mns.MNSClient) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithMnsQueueManager ¶
func (client *AliyunClient) WithMnsQueueManager(do func(ali_mns.AliQueueManager) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithMnsSubscriptionManagerByTopicName ¶
func (client *AliyunClient) WithMnsSubscriptionManagerByTopicName(topicName string, do func(ali_mns.AliMNSTopic) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithMnsTopicManager ¶
func (client *AliyunClient) WithMnsTopicManager(do func(ali_mns.AliTopicManager) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithOfficalCSClient ¶
func (client *AliyunClient) WithOfficalCSClient(do func(*officalCS.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithOssBucketByName ¶
func (*AliyunClient) WithOssClient ¶
func (client *AliyunClient) WithOssClient(do func(*oss.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithOtsClient ¶
func (client *AliyunClient) WithOtsClient(do func(*ots.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithPolarDBClient ¶
func (client *AliyunClient) WithPolarDBClient(do func(*polardb.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithRKvstoreClient ¶
func (client *AliyunClient) WithRKvstoreClient(do func(*r_kvstore.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithRamClient ¶
func (client *AliyunClient) WithRamClient(do func(*ram.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithRdsClient ¶
func (client *AliyunClient) WithRdsClient(do func(*rds.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithRkvClient ¶
func (client *AliyunClient) WithRkvClient(do func(*r_kvstore.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithSagClient ¶
func (client *AliyunClient) WithSagClient(do func(*smartag.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithSlbClient ¶
func (client *AliyunClient) WithSlbClient(do func(*slb.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithStsClient ¶
func (client *AliyunClient) WithStsClient(do func(*sts.Client) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithTableStoreClient ¶
func (client *AliyunClient) WithTableStoreClient(instanceName string, do func(*tablestore.TableStoreClient) (interface{}, error)) (interface{}, error)
func (*AliyunClient) WithVpcClient ¶
func (client *AliyunClient) WithVpcClient(do func(*vpc.Client) (interface{}, error)) (interface{}, error)
type ApiVersion ¶
type ApiVersion string
type Config ¶
type Config struct {
SourceIp string
AccessKey string
SecretKey string
EcsRoleName string
Region Region
RegionId string
SecurityToken string
OtsInstanceName string
AccountId string
Protocol string
RamRoleArn string
RamRoleSessionName string
RamRolePolicy string
RamRoleSessionExpiration int
Endpoints map[string]interface{}
RKvstoreEndpoint string
EcsEndpoint string
RdsEndpoint string
SlbEndpoint string
VpcEndpoint string
CenEndpoint string
EssEndpoint string
OssEndpoint string
OnsEndpoint string
AlikafkaEndpoint string
DnsEndpoint string
RamEndpoint string
CsEndpoint string
CrEndpoint string
CdnEndpoint string
KmsEndpoint string
OtsEndpoint string
CmsEndpoint string
PvtzEndpoint string
StsEndpoint string
LogEndpoint string
DrdsEndpoint string
DdsEndpoint string
GpdbEnpoint string
KVStoreEndpoint string
PolarDBEndpoint string
FcEndpoint string
ApigatewayEndpoint string
DatahubEndpoint string
MnsEndpoint string
LocationEndpoint string
ElasticsearchEndpoint string
NasEndpoint string
BssOpenApiEndpoint string
DdoscooEndpoint string
DdosbgpEndpoint string
SagEndpoint string
EmrEndpoint string
CasEndpoint string
MarketEndpoint string
HBaseEndpoint string
AdbEndpoint string
MaxComputeEndpoint string
SkipRegionValidation bool
ConfigurationSource string
CbnEndpoint string
DmsEnterpriseEndpoint string
WafOpenapiEndpoint string
ResourcemanagerEndpoint string
BssopenapiEndpoint string
AlidnsEndpoint string
CassandraEndpoint string
EciEndpoint string
OosEndpoint string
DcdnEndpoint string
MseEndpoint string
ActiontrailEndpoint string
ConfigEndpoint string
FnfEndpoint string
RosEndpoint string
PrivatelinkEndpoint string
MaxcomputeEndpoint string
ResourcesharingEndpoint string
GaEndpoint string
HitsdbEndpoint string
BrainIndustrialEndpoint string
EipanycastEndpoint string
ImsEndpoint string
QuotasEndpoint string
// contains filtered or unexported fields
}
Config of aliyun
func (*Config) MakeConfigByEcsRoleName ¶
type ServiceCode ¶
type ServiceCode string
ServiceCode Load endpoints from endpoints.xml or environment variables to meet specified application scenario, like private cloud.
Click to show internal directories.
Click to hide internal directories.